@@ -11,6 +11,12 @@ def _worker(app, view, *args, **kwargs):
     """
 
     d = view(*args, **kwargs)
+
+    if callable(d):
+        # We've been hoodwinked! It's pretty likely that d is a handcrafted
+        # response. Should we let it through as-is? Yes.
+        return d
+
     mime = g.mime.plain()
 
     overrides = getattr(view, "_holsters", {})
@@ -82,7 +88,7 @@ def extend(route):
         return "%s.<ext>" % route
 
 
-def bare_holster(app, route):
+def bare_holster(app, route, **kwargs):
     """
     Decorator which replaces ``route()``.
 
@@ -101,8 +107,9 @@ def bare_holster(app, route):
 
     def inner(view):
         name = view.__name__
-        app.add_url_rule(route, endpoint=name, view_func=view)
-        app.add_url_rule(extended, endpoint="%s-ext" % name, view_func=view)
+        app.add_url_rule(route, endpoint=name, view_func=view, **kwargs)
+        app.add_url_rule(extended, endpoint="%s-ext" % name, view_func=view,
+                **kwargs)
         return view
 
     return inner
